results
results
Classes
| Name | Description |
|---|---|
| Result for a query using any SAND downloader. | |
| Format a list of product dictionaries. |
Functions
| Name | Description |
|---|---|
| Extract a selection of collections from a reference table as pandas DataFrame | |
| Decorator that caches the result of a query function of SAND Downloader. |